@@ -283,7 +283,7 @@ class item(object):
         """ Returns a list of classes that _can_ use the item. """
         sitem = self._schema_item
 
-        return [c for c in sitem.get("used_by_classes", self.equipped.keys()) if c]
+        return [c for c in sitem.get("used_by_classes", []) if c]
 
     @property
     def schema_id(self):
